@@ -11,6 +11,10 @@ import gettext
 t = gettext.translation(GETTEXT_PACKAGE, localedir, fallback=True)
 _ = t.ugettext
 
+# make sure that sys.stdout.write() works ok with UTF-8 data for all translations
+import codecs, locale
+sys.stdout = codecs.getwriter(locale.getpreferredencoding())(sys.stdout)
+
 standardFailMessage = _("\n\
 Common problems are:\n\
 \n\
@@ -19,10 +23,9 @@ Common problems are:\n\
           Linux  : run as 'root' user\n\
           Windows: run as 'administrator' user\n\
 \n\
-    -- dell_rbu or dcdbas device drivers not loaded.\n\
-       Try loading the dell_rbu driver\n\
-          Linux  : modprobe dell_rbu\n\
-          Windows: dell_rbu driver not yet available.\n\
+    -- dcdbas device driver not loaded.\n\
+       Try loading the dcdbas driver\n\
+          Linux  : modprobe dcdbas\n\
 ")
 
 def getStdOptionParser(usage, version):
@@ -106,7 +109,7 @@ def wrap(s, line_len=80, indent=0, first_line_indent=0, first_line_start=0):
     for c in s:
         sys.stdout.write(c)
         chars_printed = chars_printed + 1
-        if chars_printed > line_len:
+        if chars_printed >= line_len:
             sys.stdout.write("\n")
             chars_printed=indent
             sys.stdout.write(" "*indent)
